@@ -1,4 +1,4 @@
-"""jc - JSON Convert `top -b` command output parser
+r"""jc - JSON Convert `top -b` command output parser
 
 Requires batch mode (`-b`). The `-n` option must also be used to limit
 the number of times `top` is run.
@@ -322,6 +322,7 @@ class info():
     author_email = 'kellyjonbrazil@gmail.com'
     compatible = ['linux']
     magic_commands = ['top -b']
+    tags = ['command']
 
 
 __version__ = info.version
